changeset 2366:7a57fe6a5157 vim73

Fix that :py3file was not working.
author Bram Moolenaar <bram@vim.org>
date Wed, 21 Jul 2010 16:00:43 +0200
parents 7b7508ee56f1
children 76b7ba68a098
files runtime/doc/if_pyth.txt runtime/doc/index.txt runtime/doc/todo.txt src/ex_cmds.h src/ex_docmd.c
diffstat 5 files changed, 15 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/runtime/doc/if_pyth.txt
+++ b/runtime/doc/if_pyth.txt
@@ -1,4 +1,4 @@
-*if_pyth.txt*   For Vim version 7.3b.  Last change: 2010 Jul 20
+*if_pyth.txt*   For Vim version 7.3b.  Last change: 2010 Jul 21
 
 
 		  VIM REFERENCE MANUAL    by Paul Moore
@@ -335,7 +335,7 @@ 7. Python 3						*python3*
 
 Python 3 support can exist next to Python 2.x.
 
-*:py3* *:py3file*
+*:py3* *:python3* *:py3file*
 
 TODO
 
--- a/runtime/doc/index.txt
+++ b/runtime/doc/index.txt
@@ -1,4 +1,4 @@
-*index.txt*     For Vim version 7.3b.  Last change: 2010 Jul 20
+*index.txt*     For Vim version 7.3b.  Last change: 2010 Jul 21
 
 
 		  VIM REFERENCE MANUAL    by Bram Moolenaar
@@ -1383,7 +1383,8 @@ The commands are sorted on the non-optio
 |:put|		:pu[t]		insert contents of register in the text
 |:pwd|		:pw[d]		print current directory
 |:py3|		:py3		execute Python 3 command
-|:p3yfile|	:py3f[ile]	execute Python 3 script file
+|:python3|	:python3	same as :py3
+|:py3yfile|	:py3f[ile]	execute Python 3 script file
 |:python|	:py[thon]	execute Python command
 |:pyfile|	:pyf[ile]	execute Python script file
 |:quit|		:q[uit]		quit current window (when one window quit Vim)
--- a/runtime/doc/todo.txt
+++ b/runtime/doc/todo.txt
@@ -30,6 +30,10 @@ be worked on, but only if you sponsor Vi
 							*known-bugs*
 -------------------- Known bugs and current work -----------------------
 
+Include patch for horizontal scoll wheel? (Bjorn Winckler, 2010 Jul 20)
+
+Patch for Dynamic loading for Perl. (James Vega, 2010 Jul 20)
+
 Cursor positioning wrong with 0x200e character. (John Becket, 2010 May 6)
 
 Test 69 breaks on MS-Windows, both 32 and 64 builds. (George Reilly, 2010 Feb
--- a/src/ex_cmds.h
+++ b/src/ex_cmds.h
@@ -743,6 +743,8 @@ EX(CMD_pyfile,		"pyfile",	ex_pyfile,
 			RANGE|FILE1|NEEDARG|CMDWIN),
 EX(CMD_py3,		"py3",		ex_py3,
 			RANGE|EXTRA|NEEDARG|CMDWIN),
+EX(CMD_python3,		"python3",	ex_py3,
+			RANGE|EXTRA|NEEDARG|CMDWIN),
 EX(CMD_py3file,		"py3file",	ex_py3file,
 			RANGE|FILE1|NEEDARG|CMDWIN),
 EX(CMD_quit,		"quit",		ex_quit,
--- a/src/ex_docmd.c
+++ b/src/ex_docmd.c
@@ -2563,6 +2563,7 @@ do_one_cmd(cmdlinep, sourcing,
 	    case CMD_psearch:
 	    case CMD_python:
 	    case CMD_py3:
+	    case CMD_python3:
 	    case CMD_return:
 	    case CMD_rightbelow:
 	    case CMD_ruby:
@@ -2825,9 +2826,10 @@ find_command(eap, full)
     {
 	while (ASCII_ISALPHA(*p))
 	    ++p;
 	/* for python 3.x support ":py3" (and ":py4" :-) */
 	if (eap->cmd[0] == 'p' && eap->cmd[1] == 'y')
-	    p = skipdigits(p);
+	    while (ASCII_ISALNUM(*p))
+		++p;
 
 	/* check for non-alpha command */
 	if (p == eap->cmd && vim_strchr((char_u *)"@*!=><&~#", *p) != NULL)
@@ -2825,9 +2826,10 @@ find_command(eap, full)
 	while (ASCII_ISALPHA(*p))
 	    ++p;
-	/* for python 3.x support ":py3" (and ":py4" :-) */
+	/* for python 3.x support ":py3", ":python3", ":py3file", etc. */
 	if (eap->cmd[0] == 'p' && eap->cmd[1] == 'y')